/// <reference path="../native.ts" />
/// <reference path="../object.ts" />

namespace trusted.pki {
    /**
     * Collection of CRL
     *
     * @export
     * @class CrlCollection
     * @extends {BaseObject<native.PKI.CrlCollection>}
     * @implements {core.ICollectionWrite}
     */
    export class CrlCollection extends BaseObject<native.PKI.CrlCollection>
        implements core.ICollectionWrite {

        /**
         * Creates an instance of CrlCollection.
         * @param {native.PKI.CrlCollection} [param]
         *
         * @memberOf CrlCollection
         */
        constructor(param?: native.PKI.CrlCollection) {
            super();
            if (param instanceof native.PKI.CrlCollection) {
                this.handle = param;
            } else {
                this.handle = new native.PKI.CrlCollection();
            }
        }

        /**
         * Return element by index from collection
         *
         * @param {number} index
         * @returns {CRL}
         *
         * @memberOf CrlCollection
         */
        public items(index: number): CRL {
            return CRL.wrap<native.PKI.CRL, CRL>(this.handle.items(index));
        }

        /**
         * Return collection length
         *
         * @readonly
         * @type {number}
         * @memberOf CrlCollection
         */
        get length(): number {
            return this.handle.length();
        }

        /**
         * Add new element to collection
         *
         * @param {CRL} cert
         *
         * @memberOf CrlCollection
         */
        public push(crl: CRL): void {
            this.handle.push(crl.handle);
        }

        /**
         * Remove last element from collection
         *
         *
         * @memberOf CrlCollection
         */
        public pop(): void {
            this.handle.pop();
        }

        /**
         * Remove element by index from collection
         *
         * @param {number} index
         *
         * @memberOf CrlCollection
         */
        public removeAt(index: number): void {
            this.handle.removeAt(index);
        }
    }
}
