/// <reference path="../native.ts" />
/// <reference path="../object.ts" />

namespace trusted.utils {
    /**
     * Connection settings for TSP and OCSP
     *
     * @export
     * @class ConnectionSettings
     * @extends {BaseObject<native.UTILS.ConnectionSettings>}
     */
    export class ConnectionSettings extends BaseObject<native.UTILS.ConnectionSettings> {
        /**
         * Service authentication type getter
         *
         *
         * @type {number}
         * @memberof ConnectionSettings
         */
        get AuthType(): number {
            return this.handle.AuthType;
        }

        /**
         * Service authentication type setter
         *
         *
         * @type {number}
         * @memberof ConnectionSettings
         */
        set AuthType(authType: number) {
            this.handle.AuthType = authType;
        }

        /**
         * Service address getter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        get Address(): string {
            return this.handle.Address;
        }

        /**
         * Service address setter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        set Address(addr: string) {
            this.handle.Address = addr;
        }

        /**
         * Service user name getter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        get UserName(): string {
            return this.handle.UserName;
        }

        /**
         * Service user name setter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        set UserName(usrName: string) {
            this.handle.UserName = usrName;
        }

        /**
         * Service password getter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        get Password(): string {
            return this.handle.Password;
        }

        /**
         * Service password setter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        set Password(passwd: string) {
            this.handle.Password = passwd;
        }

        /**
         * Client certificate getter
         *
         *
         * @type {pki.Certificate}
         * @memberof ConnectionSettings
         */
        get ClientCertificate(): pki.Certificate {
            const cert = this.handle.ClientCertificate;

            if (cert) {
                return pki.Certificate.wrap<native.PKI.Certificate, pki.Certificate>(cert);
            } else {
                return undefined;
            }
        }

        /**
         * Client certificate setter
         *
         *
         * @type {pki.Certificate}
         * @memberof ConnectionSettings
         */
        set ClientCertificate(clntCert: pki.Certificate) {
            if( clntCert !== undefined ) {
                this.handle.ClientCertificate = clntCert.handle;
            }
            else {
                this.handle.ClientCertificate = undefined;
            }
        }

        /**
         * Proxy authentication type getter
         *
         *
         * @type {number}
         * @memberof ConnectionSettings
         */
        get ProxyAuthType(): number {
            return this.handle.ProxyAuthType;
        }

        /**
         * Proxy authentication type setter
         *
         *
         * @type {number}
         * @memberof ConnectionSettings
         */
        set ProxyAuthType(authType: number) {
            this.handle.ProxyAuthType = authType;
        }

        /**
         * Proxy address getter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        get ProxyAddress(): string {
            return this.handle.ProxyAddress;
        }

        /**
         * Proxy address setter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        set ProxyAddress(addr: string) {
            this.handle.ProxyAddress = addr;
        }

        /**
         * Proxy user name getter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        get ProxyUserName(): string {
            return this.handle.ProxyUserName;
        }

        /**
         * Proxy user name setter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        set ProxyUserName(usrName: string) {
            this.handle.ProxyUserName = usrName;
        }

        /**
         * Proxy password getter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        get ProxyPassword(): string {
            return this.handle.ProxyPassword;
        }

        /**
         * Proxy password setter
         *
         *
         * @type {string}
         * @memberof ConnectionSettings
         */
        set ProxyPassword(passwd: string) {
            this.handle.ProxyPassword = passwd;
        }

        /**
         * Creates an instance of ConnectionSettings.
         *
         *
         * @memberOf ConnectionSettings
         */
        constructor() {
            super();
            this.handle = new native.UTILS.ConnectionSettings();
        }
    }
}
