/// <reference path="../native.ts" />
/// <reference path="../object.ts" />

namespace trusted.utils {
    /**
     * JSON Web Token (DLV)
     * Uses only with CTGOSTCP
     *
     * @export
     * @class Dlv
     * @extends {BaseObject<native.DLV.DLV>}
     */
    export class Dlv extends BaseObject<native.UTILS.Dlv> {
        /**
         * Add dlv license to store
         * License must be correct
         *
         * @static
         * @param {string} license license token in DLV format
         * @returns {boolean}
         * @memberof Dlv
         */

        constructor() {
            super();
            this.handle = new native.UTILS.Dlv();
        }

        /**
         * Verify dlv license file
         * Return 0 if license correct
         *
         * @returns {number}
         *
         * @memberOf Dlv
         */
        public licenseValidateFormat(lic: string): boolean {
            return this.handle.licenseValidateFormat(lic);
        }

        /**
         * Verify dlv license file
         * Return 0 if license correct
         *
         * @returns {number}
         *
         * @memberOf Dlv
         */
        public checkLicense(lic: string): string {
            return this.handle.checkLicense(lic);
        }      
    }
}
